==> glx.ui-1.9.3.tgz: package/components/fileInput/fileInput.ts <==
import { Component, EventEmitter, HostListener, Input, NgModule, OnInit, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { DomSanitizer } from '@angular/platform-browser';
import { AuthHttp } from 'angular2-jwt';
import { Http } from '@angular/http';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';

@Component({
    selector: 'glx-file-input',
    styleUrls: ['fileInput.scss'],
    templateUrl: 'fileInput.html'
})

export class FileInput implements OnInit {
    @Input() multiple: boolean = true;
    @Input() mode: string = 'area';
    @Input() btnText: string = 'Выбрать файл';
    @Input() btnIcon: string;
    @Input() btnClass: string = 'btn btn-primary';
    @Input() maxFileSize: number;
    @Input() disabled: boolean = false;
    @Input() accept: string;
    @Input() url: string = '/api/attachments/upload';
    @Input() secure: boolean = true;
    @Input() hideFiles: boolean = false;
    @Input() globalCatcher: boolean = false;
    @Input() copyPasteCatcher: boolean = false;

    files: File[] = [];
    uploadedFiles: any[] = [];
    msgs: any;
    progress: number = 0;
    dragHighlight: boolean;

    @Output() onChange: EventEmitter<any> = new EventEmitter();

    constructor(private sanitizer: DomSanitizer,
                private authHttp: AuthHttp,
                private http: Http) {
    }

    ngOnInit() {

    }

    @HostListener('document:paste', ['$event'])
    onPaste(event: ClipboardEvent) {
        if (this.copyPasteCatcher) {
            const items = event.clipboardData.items;
            for (let i = 0; i < items.length; i++) {
                // Skip content if not image
                if (items[i].type.indexOf('image') === -1) {
                    continue;
                }
                // Retrieve image on clipboard as blob
                const file = items[i].getAsFile();
                if (this.validate(file)) {
                    this.files.push(file);
                }

                this.upload();

                this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
            }
        }
    }


    onChooseClick(fileInput) {
        fileInput.value = null;
        fileInput.click();
    }

    onFileSelect(event) {
        this.msgs = [];
        if (!this.multiple) {
            this.files = [];
        }

        const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            if (this.validate(file)) {
                if (this.isImage(file)) {
                    file.objectURL = this.sanitizer.bypassSecurityTrustUrl((window.URL.createObjectURL(files[i])));
                }

                this.files.push(files[i]);
            }
        }
        this.upload();

        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});

    }

    upload() {
        for (let i = 0; i < this.files.length; i++) {
            const file: File = this.files[i];
            const formData: FormData = new FormData();
            formData.append('file', file, file.name);

            if (this.secure) {
                this.authHttp.post(this.url, formData)
                    .map(res => res.json())
                    .catch(error => Observable.throw(error))
                    .subscribe(
                        data => {
                            this.uploadedFiles.push({
                                file: file,
                                path: data.path,
                                name: file.name
                            });
                        },
                        error => {
                            console.error(error);
                        }
                    );
            } else {
                this.http.post(this.url, formData)
                    .map(res => res.json())
                    .catch(error => Observable.throw(error))
                    .subscribe(
                        data => {
                            this.uploadedFiles.push({
                                file: file,
                                path: data.path,
                                name: file.name
                            });
                        },
                        error => {
                            console.error(error);
                            if (this.url === '') {
                                this.uploadedFiles.push({
                                    file: file,
                                    path: 'tmp/' + file.name,
                                    name: file.name
                                });
                            }
                        }
                    );
            }


        }
        this.files = [];
    }

    validate(file: File): boolean {
        if (this.accept && !this.isFileTypeValid(file)) {
            this.msgs.push({
                severity: 'error',
                summary: 'Неверный тип файла',
                detail: 'Неверный тип файла'
            });
            return false;
        }

        if (this.maxFileSize && file.size > this.maxFileSize) {
            this.msgs.push({
                severity: 'error',
                summary: 'Неверный размер файла',
                detail: 'Неверный размер файла'
            });
            return false;
        }

        return true;
    }

    private isFileTypeValid(file: File): boolean {
        const acceptableTypes = this.accept.split(',');
        for (const type of acceptableTypes) {
            const acceptable = this.isWildcard(type) ? this.getTypeClass(file.type) === this.getTypeClass(type)
                : this.getFileExtension(file) === type;

            if (acceptable) {
                return true;
            }
        }

        return false;
    }

    getTypeClass(fileType: string): string {
        return fileType.substring(0, fileType.indexOf('/'));
    }

    isWildcard(fileType: string): boolean {
        return fileType.indexOf('*') !== -1;
    }

    getFileExtension(file: File): string {
        return '.' + file.name.split('.').pop();
    }

    isImage(file: File): boolean {
        return /^image\//.test(file.type);
    }

    isVideo(file: File): boolean {
        return /^video\//.test(file.type);
    }

    isAudio(file: File): boolean {
        return /^audio\//.test(file.type);
    }

    hasFiles(): boolean {
        return this.uploadedFiles && this.uploadedFiles.length > 0;
    }

    getIcon(file: File) {
        if (this.isImage(file)) {
            return 'fa-file-image-o';
        }
        if (this.isVideo(file)) {
            return 'fa-file-video-o';
        }
        if (this.isAudio(file)) {
            return 'fa-file-audio-o';
        }

        switch (this.getFileExtension(file).toLowerCase()) {
            case '.zip':
            case '.rar':
            case '.7z':
            case '.gz':
            case '.jar':
                return 'fa-file-archive-o';
            case '.pdf':
                return 'fa-file-pdf-o';
            case '.xls':
            case '.xlsx':
            case '.csv':
            case '.dbf':
            case '.ods':
                return 'fa-file-excel-o';
            case '.doc':
            case '.docx':
            case '.odt':
                return 'fa-file-word-o';
            case '.ppt':
            case '.pptx':
            case '.odp':
                return 'fa-file-powerpoint-o';
            case '.txt':
                return 'fa-file-text-o';
            case '.avi':
                return 'fa-file-video-o';
            case '.mp3':
                return 'fa-file-audio-o';
            case '.xml':
            case '.json':
            case '.html':
            case '.htm':
            case '.js':
            case '.php':
            case '.c':
            case '.cpp':
            case '.h':
                return 'fa-file-code-o';
            default:
                return 'fa-file-text-o';
        }
    }

    clear() {
        this.files = [];
        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
    }

    remove(index: number) {
        this.uploadedFiles.splice(index, 1);
        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
    }

    onDragEnter(e) {
        if (!this.disabled) {
            e.stopPropagation();
            e.preventDefault();
        }
    }

    onDragOver(e) {
        if (!this.disabled) {
            this.dragHighlight = true;
            e.stopPropagation();
            e.preventDefault();
        }
    }

    onDragLeave() {
        if (!this.disabled) {
            this.dragHighlight = false;
        }
    }

    onDrop(e) {
        if (!this.disabled) {
            this.dragHighlight = false;
            e.stopPropagation();
            e.preventDefault();

            this.onFileSelect(e);
        }
    }

    formatSize(bytes) {
        if (bytes === 0) {
            return '0 байт';
        }
        const k = 1000,
            dm = 3,
            sizes = ['байт', 'Кб', 'Мб', 'Гб', 'Тб', 'Пб', 'Эб', 'Зб', 'Йб'],
            i = Math.floor(Math.log(bytes) / Math.log(k));

        return Math.round(parseFloat((bytes / Math.pow(k, i)).toFixed(dm))) + '&nbsp;' + sizes[i];
    }

    getFileNameWord() {
        const titles = ['файл', 'файла', 'файлов'];
        const l = this.uploadedFiles.length;
        const cases = [2, 0, 1, 1, 1, 2];
        return titles[
            (l % 100 > 4 && l % 100 < 20)
                ?
                2
                :
                cases[(l % 10 < 5) ? l % 10 : 5]
            ];
    }
}


@NgModule({
    imports: [CommonModule, OverlayPanelModule],
    exports: [FileInput],
    declarations: [FileInput]
})
export class FileInputModule {
}

==> glx.ui-2.0.0.tgz: package/components/fileInput/fileInput.ts <==
import { Component, EventEmitter, HostListener, Input, NgModule, OnInit, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { DomSanitizer } from '@angular/platform-browser';
import { HttpClient } from '@angular/common/http';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';

@Component({
    selector: 'glx-file-input',
    styleUrls: ['fileInput.scss'],
    templateUrl: 'fileInput.html'
})

export class FileInput implements OnInit {
    @Input() multiple: boolean = true;
    @Input() mode: string = 'area';
    @Input() btnText: string = 'Выбрать файл';
    @Input() btnIcon: string;
    @Input() btnClass: string = 'btn btn-primary';
    @Input() maxFileSize: number;
    @Input() disabled: boolean = false;
    @Input() accept: string;
    @Input() url: string = '/api/attachments/upload';
    @Input() secure: boolean = true;
    @Input() hideFiles: boolean = false;
    @Input() globalCatcher: boolean = false;
    @Input() copyPasteCatcher: boolean = false;

    files: File[] = [];
    uploadedFiles: any[] = [];
    msgs: any;
    progress: number = 0;
    dragHighlight: boolean;

    @Output() onChange: EventEmitter<any> = new EventEmitter();

    constructor(private sanitizer: DomSanitizer,
                private http: HttpClient) {
    }

    ngOnInit() {

    }

    @HostListener('document:paste', ['$event'])
    onPaste(event: ClipboardEvent) {
        if (this.copyPasteCatcher) {
            const items = event.clipboardData.items;
            for (let i = 0; i < items.length; i++) {
                // Skip content if not image
                if (items[i].type.indexOf('image') === -1) {
                    continue;
                }
                // Retrieve image on clipboard as blob
                const file = items[i].getAsFile();
                if (this.validate(file)) {
                    this.files.push(file);
                }

                this.upload();

                this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
            }
        }
    }


    onChooseClick(fileInput) {
        fileInput.value = null;
        fileInput.click();
    }

    onFileSelect(event) {
        this.msgs = [];
        if (!this.multiple) {
            this.files = [];
        }

        const files = event.dataTransfer ? event.dataTransfer.files : event.target.files;
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            if (this.validate(file)) {
                if (this.isImage(file)) {
                    file.objectURL = this.sanitizer.bypassSecurityTrustUrl((window.URL.createObjectURL(files[i])));
                }

                this.files.push(files[i]);
            }
        }
        this.upload();

        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});

    }

    upload() {
        for (let i = 0; i < this.files.length; i++) {
            const file: File = this.files[i];
            const formData: FormData = new FormData();
            formData.append('file', file, file.name);


            this.http.post<any>(this.url, formData).subscribe(
                data => {
                    this.uploadedFiles.push({
                        file: file,
                        path: data.path,
                        name: file.name
                    });
                },
                error => {
                    console.error(error);
                    if (this.url === '') {
                        this.uploadedFiles.push({
                            file: file,
                            path: 'tmp/' + file.name,
                            name: file.name
                        });
                    }
                }
            );


        }
        this.files = [];
    }

    validate(file: File): boolean {
        if (this.accept && !this.isFileTypeValid(file)) {
            this.msgs.push({
                severity: 'error',
                summary: 'Неверный тип файла',
                detail: 'Неверный тип файла'
            });
            return false;
        }

        if (this.maxFileSize && file.size > this.maxFileSize) {
            this.msgs.push({
                severity: 'error',
                summary: 'Неверный размер файла',
                detail: 'Неверный размер файла'
            });
            return false;
        }

        return true;
    }

    private isFileTypeValid(file: File): boolean {
        const acceptableTypes = this.accept.split(',');
        for (const type of acceptableTypes) {
            const acceptable = this.isWildcard(type) ? this.getTypeClass(file.type) === this.getTypeClass(type)
                : this.getFileExtension(file) === type;

            if (acceptable) {
                return true;
            }
        }

        return false;
    }

    getTypeClass(fileType: string): string {
        return fileType.substring(0, fileType.indexOf('/'));
    }

    isWildcard(fileType: string): boolean {
        return fileType.indexOf('*') !== -1;
    }

    getFileExtension(file: File): string {
        return '.' + file.name.split('.').pop();
    }

    isImage(file: File): boolean {
        return /^image\//.test(file.type);
    }

    isVideo(file: File): boolean {
        return /^video\//.test(file.type);
    }

    isAudio(file: File): boolean {
        return /^audio\//.test(file.type);
    }

    hasFiles(): boolean {
        return this.uploadedFiles && this.uploadedFiles.length > 0;
    }

    getIcon(file: File) {
        if (this.isImage(file)) {
            return 'fa-file-image-o';
        }
        if (this.isVideo(file)) {
            return 'fa-file-video-o';
        }
        if (this.isAudio(file)) {
            return 'fa-file-audio-o';
        }

        switch (this.getFileExtension(file).toLowerCase()) {
            case '.zip':
            case '.rar':
            case '.7z':
            case '.gz':
            case '.jar':
                return 'fa-file-archive-o';
            case '.pdf':
                return 'fa-file-pdf-o';
            case '.xls':
            case '.xlsx':
            case '.csv':
            case '.dbf':
            case '.ods':
                return 'fa-file-excel-o';
            case '.doc':
            case '.docx':
            case '.odt':
                return 'fa-file-word-o';
            case '.ppt':
            case '.pptx':
            case '.odp':
                return 'fa-file-powerpoint-o';
            case '.txt':
                return 'fa-file-text-o';
            case '.avi':
                return 'fa-file-video-o';
            case '.mp3':
                return 'fa-file-audio-o';
            case '.xml':
            case '.json':
            case '.html':
            case '.htm':
            case '.js':
            case '.php':
            case '.c':
            case '.cpp':
            case '.h':
                return 'fa-file-code-o';
            default:
                return 'fa-file-text-o';
        }
    }

    clear() {
        this.files = [];
        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
    }

    remove(index: number) {
        this.uploadedFiles.splice(index, 1);
        this.onChange.emit({originalEvent: event, files: this.uploadedFiles});
    }

    onDragEnter(e) {
        if (!this.disabled) {
            e.stopPropagation();
            e.preventDefault();
        }
    }

    onDragOver(e) {
        if (!this.disabled) {
            this.dragHighlight = true;
            e.stopPropagation();
            e.preventDefault();
        }
    }

    onDragLeave() {
        if (!this.disabled) {
            this.dragHighlight = false;
        }
    }

    onDrop(e) {
        if (!this.disabled) {
            this.dragHighlight = false;
            e.stopPropagation();
            e.preventDefault();

            this.onFileSelect(e);
        }
    }

    formatSize(bytes) {
        if (bytes === 0) {
            return '0 байт';
        }
        const k = 1000,
            dm = 3,
            sizes = ['байт', 'Кб', 'Мб', 'Гб', 'Тб', 'Пб', 'Эб', 'Зб', 'Йб'],
            i = Math.floor(Math.log(bytes) / Math.log(k));

        return Math.round(parseFloat((bytes / Math.pow(k, i)).toFixed(dm))) + '&nbsp;' + sizes[i];
    }

    getFileNameWord() {
        const titles = ['файл', 'файла', 'файлов'];
        const l = this.uploadedFiles.length;
        const cases = [2, 0, 1, 1, 1, 2];
        return titles[
            (l % 100 > 4 && l % 100 < 20)
                ?
                2
                :
                cases[(l % 10 < 5) ? l % 10 : 5]
            ];
    }
}


@NgModule({
    imports: [CommonModule, OverlayPanelModule],
    exports: [FileInput],
    declarations: [FileInput]
})
export class FileInputModule {
}
